from django.contrib.auth.decorators import permission_required
from django.core.exceptions import ValidationError
from django.db import transaction
from django.shortcuts import get_object_or_404

from common.decorators import ajax
from unifier.models import UnifiedFrame, UnifiedFrame2SlowalFrameMapping
from users.models import Assignment

from . import choices
from .models import Frame


@ajax(login_required=True, method='post')
@transaction.atomic
def frame_mark_as_invalid(request, frame_pk):
    frame = get_object_or_404(Frame.objects.filter(status=choices.FrameStatus.NEW).select_for_update(), pk=frame_pk)
    frame.status = choices.FrameStatus.INVALID
    frame.save()
    return {}

@ajax(login_required=True, method='post')
@transaction.atomic
@permission_required('semantics.manage_invalid_lexical_units')
def frame_confirm_invalid(request, frame_pk):
    frame = get_object_or_404(Frame.objects.filter(status=choices.FrameStatus.INVALID).select_for_update(), pk=frame_pk)
    frame.status = choices.FrameStatus.BAD
    frame.save()
    return {}


@ajax(login_required=True, method='post')
@transaction.atomic
@permission_required('semantics.manage_invalid_lexical_units')
def frame_reject_invalid(request, frame_pk):
    frame = get_object_or_404(Frame.objects.filter(status=choices.FrameStatus.INVALID).select_for_update(), pk=frame_pk)
    frame.status = choices.FrameStatus.NEW
    frame.save()
    return {}
